<?php
// ---------------------------------------------------------------------------------------
// API__SHELL_PROXY (INTERFACE)
// CLS__SHELL_PROXY (CLASS)
// ---------------------------------------------------------------------------------------
interface api__shell_proxy
{
	public static function proxy_isset();
	public static function proxy_set( $proxy_host, $proxy_port, $proxy_user = null, $proxy_pass = null );
	public static function proxy_get( $url );
}
// ---------------------------------------------------------------------------------------
// LICENSE (BSD)
//
//	Copyright (c) 2010, Gerd Christian Kunze
//	All rights reserved.
//
//	Redistribution and use in source and binary forms, with or without
//	modification, are permitted provided that the following conditions are
//	met:
//
//		* Redistributions of source code must retain the above copyright
//		  notice, this list of conditions and the following disclaimer.
//		* Redistributions in binary form must reproduce the above copyright
//		  notice, this list of conditions and the following disclaimer in the
//		  documentation and/or other materials provided with the distribution.
//		* Neither the name of the Gerd Christian Kunze nor the names of its
//		  contributors may be used to endorse or promote products derived from
//		  this software without specific prior written permission.
//
//	THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
//	IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
//	THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
//	PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
//	CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
//	EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
//	PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
//	PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
//	LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
//	NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
//	SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// ---------------------------------------------------------------------------------------
//  Based on http://www.php.net/manual/de/function.fopen.php#47224
// ---------------------------------------------------------------------------------------
class cls__shell_proxy implements api__shell_proxy
{
	private static $proxy_host = null;
	private static $proxy_port = null;
	private static $proxy_user = null;
	private static $proxy_pass = null;

	private static $proxy_timeout = 2;
	private static $proxy_isset = false;

	private static $proxy_error_number = null;
	private static $proxy_error_string = null;
// ---------------------------------------------------------------------------------------
	public static function proxy_isset(){
		return (self::$proxy_isset?true:false);
	}
	public static function proxy_set( $proxy_host, $proxy_port, $proxy_user = null, $proxy_pass = null ){
		self::proxy_host( $proxy_host );
		self::proxy_port( $proxy_port );
		self::proxy_user( $proxy_user );
		self::proxy_pass( $proxy_pass );
		self::$proxy_isset = true;
	}
	public static function proxy_get( $url ){
		if( $resource_fsock = @fsockopen( self::proxy_host(), self::proxy_port(), self::$proxy_error_number, self::$proxy_error_string, self::$proxy_timeout ) ) {
			$string_return = '';
			fputs( $resource_fsock, "GET ".$url." HTTP/1.0\r\nHost: ".self::proxy_host()."\r\n");
			if( self::proxy_user() === null ) {
				fputs( $resource_fsock, "\r\n" );
			} else {
				fputs( $resource_fsock, "Proxy-Authorization: Basic ".base64_encode( self::proxy_user().':'.self::proxy_pass() ) . "\r\n\r\n");
			}
			while( !feof( $resource_fsock ) ) {
				$string_return .= fread( $resource_fsock, 4096 );
			}
			fclose( $resource_fsock );
			$string_return = substr( $string_return, strpos( $string_return, "\r\n\r\n" ) +4 );
		} else {
			trigger_error( '['.self::$proxy_error_number.'] '.self::$proxy_error_string );
			$string_return = null;
		}
		return $string_return;
	}
// ---------------------------------------------------------------------------------------
// SET / GET
	private static function proxy_host( $proxy_name = null ){
		if( $proxy_name !== null ) self::$proxy_host = $proxy_name;
		return self::$proxy_host;
	}
	private static function proxy_port( $proxy_port = null ){
		if( $proxy_port !== null ) self::$proxy_port = $proxy_port;
		return self::$proxy_port;
	}
	private static function proxy_user( $proxy_user = null ){
		if( $proxy_user !== null ) self::$proxy_user = $proxy_user;
		return self::$proxy_user;
	}
	private static function proxy_pass( $proxy_pass = null ){
		if( $proxy_pass !== null ) self::$proxy_pass = $proxy_pass;
		return self::$proxy_pass;
	}
}
?>